"""Example calculator module under `arua` package."""

from __future__ import annotations


def add(a: float, b: float) -> float:
    return a + b


def multiply(a: float, b: float) -> float:
    return a * b
